@@ -36,8 +36,9 @@
  dependencies:     juce_audio_basics, juce_audio_devices, juce_audio_formats,
                    juce_audio_plugin_client, juce_audio_processors,
                    juce_audio_utils, juce_core, juce_data_structures,
-                   juce_events, juce_graphics, juce_gui_basics, juce_gui_extra
- exporters:        xcode_mac, vs2022
+                   juce_events, juce_graphics, juce_gui_basics, juce_gui_extra,
+                   juce_audio_processors_headless
+ exporters:        xcode_mac, vs2022, vs2026
 
  moduleFlags:      JUCE_STRICT_REFCOUNTEDPOINTER=1
 
