@@ -163,10 +163,10 @@ public:
         This will attempt to open either a default audio device, or one that was
         previously saved as XML.
 
-        @param numInputChannelsNeeded       the maximum number of input channels your app would like to
+        @param maxNumInputChannelsNeeded    the maximum number of input channels your app would like to
                                             use (the actual number of channels opened may be less than
                                             the number requested)
-        @param numOutputChannelsNeeded      the maximum number of output channels your app would like to
+        @param maxNumOutputChannelsNeeded   the maximum number of output channels your app would like to
                                             use (the actual number of channels opened may be less than
                                             the number requested)
         @param savedState                   either a previously-saved state that was produced
@@ -191,8 +191,8 @@ public:
 
         @returns an error message if anything went wrong, or an empty string if it worked ok.
     */
-    String initialise (int numInputChannelsNeeded,
-                       int numOutputChannelsNeeded,
+    String initialise (int maxNumInputChannelsNeeded,
+                       int maxNumOutputChannelsNeeded,
                        const XmlElement* savedState,
                        bool selectDefaultDeviceOnFailure,
                        const String& preferredDefaultDeviceName = String(),
