@@ -67,7 +67,7 @@ public:
         This is the number of samples from the start of an edit that the
         file is supposed to begin at. Seems like an obvious mistake to
         only allow a file to occur in an edit once, but that's the way
-        it is..
+        it is.
 
         @see AudioFormatReader::metadataValues, createWriterFor
     */
