@@ -118,8 +118,9 @@ using namespace juce;
 #include <juce_audio_plugin_client/detail/juce_LinuxMessageThread.h>
 #include <juce_audio_plugin_client/detail/juce_VSTWindowUtilities.h>
 
-#include <juce_audio_processors/format_types/juce_LegacyAudioParameter.cpp>
-#include <juce_audio_processors/format_types/juce_VSTCommon.h>
+#include <juce_audio_processors_headless/format_types/juce_LegacyAudioParameter.h>
+#include <juce_audio_processors_headless/format_types/juce_VSTCommon.h>
+#include <juce_audio_processors_headless/format_types/juce_VSTMidiEventList.h>
 
 #ifdef JUCE_MSVC
  #pragma pack (pop)
@@ -397,8 +398,8 @@ public:
             // if this fails, the host hasn't called resume() before processing
             jassert (isProcessing);
 
-            // (tragically, some hosts actually need this, although it's stupid to have
-            //  to do it here.)
+            // (tragically, some hosts actually need this, although it's unfortunate to have
+            //  to do it here)
             if (! isProcessing)
                 resume();
 
@@ -453,10 +454,10 @@ public:
                             }
                         }
 
-                        // if some output channels are disabled, some hosts supply the same buffer
+                        // If some output channels are disabled, some hosts supply the same buffer
                         // for multiple channels or supply a nullptr - this buggers up our method
                         // of copying the inputs over the outputs, so we need to create unique temp
-                        // buffers in this case..
+                        // buffers in this case.
                         if (bufferPointerReusedForOtherChannels || chan == nullptr)
                         {
                             chan = new FloatType [(size_t) blockSize * 2];
@@ -490,7 +491,7 @@ public:
                         processor->processBlock (chans, midiEvents);
                 }
 
-                // copy back any temp channels that may have been used..
+                // copy back any temp channels that may have been used
                 for (i = 0; i < numOut; ++i)
                     if (auto* chan = tmpBuffers.tempChannels.getUnchecked (i))
                         if (auto* dest = outputs[i])
@@ -862,8 +863,8 @@ public:
 
                 editorComp = nullptr;
 
-                // there's some kind of component currently modal, but the host
-                // is trying to delete our plugin. You should try to avoid this happening..
+                // There's some kind of component currently modal, but the host
+                // is trying to delete our plugin. You should try to avoid this happening.
                 jassert (Component::getCurrentlyModalComponent() == nullptr);
             }
         }
@@ -1083,7 +1084,7 @@ public:
                 }
             }
 
-            // some hosts don't support the sizeWindow call, so do it manually..
+            // some hosts don't support the sizeWindow call, so do it manually
             if (! sizeWasSuccessful)
             {
                 const ScopedValueSetter<bool> resizingParentSetter (resizingParent, true);
@@ -1353,7 +1354,7 @@ private:
 
     //==============================================================================
    #if JUCE_WINDOWS
-    // Workarounds for hosts which attempt to open editor windows on a non-GUI thread.. (Grrrr...)
+    // Workarounds for hosts which attempt to open editor windows on a non-GUI thread. (Grrrr...)
     static void checkWhetherMessageThreadIsCorrect()
     {
         auto host = detail::PluginUtilities::getHostType();
@@ -1497,7 +1498,7 @@ private:
     {
         if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
+            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more
             param->getLabel().copyToUTF8 ((char*) args.ptr, 24 + 1);
         }
 
@@ -1508,7 +1509,7 @@ private:
     {
         if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
+            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more
             param->getCurrentValueAsText().copyToUTF8 ((char*) args.ptr, 24 + 1);
         }
 
@@ -1519,7 +1520,7 @@ private:
     {
         if (auto* param = juceParameters.getParamForIndex (args.index))
         {
-            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more.
+            // length should technically be kVstMaxParamStrLen, which is 8, but hosts will normally allow a bit more
             param->getName (32).copyToUTF8 ((char*) args.ptr, 32 + 1);
         }
 
@@ -2188,7 +2189,7 @@ namespace
 JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wmissing-prototypes")
 
 //==============================================================================
-// Mac startup code..
+// Mac startup code
 #if JUCE_MAC
 
     JUCE_EXPORTED_FUNCTION Vst2::AEffect* VSTPluginMain (Vst2::audioMasterCallback audioMaster);
@@ -2204,7 +2205,7 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wmissing-prototypes")
     }
 
 //==============================================================================
-// Linux startup code..
+// Linux startup code
 #elif JUCE_LINUX || JUCE_BSD
 
     JUCE_EXPORTED_FUNCTION Vst2::AEffect* VSTPluginMain (Vst2::audioMasterCallback audioMaster);
@@ -2224,7 +2225,7 @@ JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wmissing-prototypes")
     __attribute__ ((destructor))  void myPluginFini() {}
 
 //==============================================================================
-// Win32 startup code..
+// Win32 startup code
 #else
 
     extern "C" __declspec (dllexport) Vst2::AEffect* VSTPluginMain (Vst2::audioMasterCallback audioMaster)
