@@ -32,9 +32,9 @@
   ==============================================================================
 */
 
-#include "juce_VST3Headers.h"
-#include "juce_VST3Utilities.h"
-#include "juce_VST3Common.h"
+#include <juce_audio_processors_headless/format_types/juce_VST3Headers.h>
+#include <juce_audio_processors_headless/format_types/juce_VST3Utilities.h>
+#include <juce_audio_processors_headless/format_types/juce_VST3Common.h>
 
 namespace juce
 {
