@@ -342,7 +342,7 @@ void TextLayout::createLayoutWithBalancedLineLengths (const AttributedString& te
             for (const auto& line : lines)
                 for (const auto& run : line->runs)
                     for (const auto& glyph : run->glyphs)
-                        advanceWidth = jmin (*advanceWidth, glyph.width);
+                        advanceWidth = jmin (*advanceWidth, jmax (glyph.width, 1.0f));
         }
 
         maxWidth -= *advanceWidth;
@@ -445,7 +445,6 @@ void TextLayout::createStandardLayout (const AttributedString& text)
     }
 
     auto shapedTextOptions = ShapedTextOptions{}.withFonts (fonts)
-                                                .withLanguage (SystemStats::getUserLanguage())
                                                 .withTrailingWhitespacesShouldFit (false)
                                                 .withJustification (justification)
                                                 .withReadingDirection (getTextDirection (text))
