@@ -212,114 +212,23 @@ public:
     */
     void subtract (const RectangleType rect)
     {
-        if (auto numRects = rects.size())
+        if (rects.isEmpty())
+            return;
+
+        if constexpr (std::is_floating_point_v<ValueType>)
         {
-            const auto x1 = rect.getX();
-            const auto y1 = rect.getY();
-            const auto x2 = x1 + rect.getWidth();
-            const auto y2 = y1 + rect.getHeight();
+            Array<AABB> alternativeRepresentation;
+            alternativeRepresentation.resize (rects.size());
+            std::copy (rects.begin(), rects.end(), alternativeRepresentation.begin());
 
-            for (int i = numRects; --i >= 0;)
-            {
-                auto& r = rects.getReference (i);
+            subtract (alternativeRepresentation, rect);
 
-                const auto rx1 = r.getX();
-                const auto ry1 = r.getY();
-                const auto rx2 = rx1 + r.getWidth();
-                const auto ry2 = ry1 + r.getHeight();
-
-                const auto isNotEqual = [&] (const RectangleType newRect)
-                {
-                    // When subtracting tiny slices from relatively large rectangles, the
-                    // subtraction may have no effect (due to limited-precision floating point
-                    // maths) and the original rectangle may remain unchanged.
-                    // We check that any 'new' rectangle has different dimensions to the rectangle
-                    // being tested before adding it to the rects array.
-                    // Integer arithmetic is not susceptible to this problem, so there's no need
-                    // for this additional equality check when working with integral rectangles.
-                    if constexpr (std::is_floating_point_v<ValueType>)
-                    {
-                        return newRect != r;
-                    }
-                    else
-                    {
-                        ignoreUnused (newRect);
-                        return true;
-                    }
-                };
-
-                if (rx1 < x2 && x1 < rx2 && ry1 < y2 && y1 < ry2)
-                {
-                    if (rx1 < x1 && x1 < rx2)
-                    {
-                        if (y1 <= ry1 && ry2 <= y2 && rx2 <= x2)
-                        {
-                            r.setWidth (x1 - rx1);
-                        }
-                        else
-                        {
-                            if (const RectangleType newRect (rx1, ry1, x1 - rx1, ry2 - ry1); isNotEqual (newRect))
-                            {
-                                r.setX (x1);
-                                r.setWidth (rx2 - x1);
-
-                                rects.insert (++i, newRect);
-                                ++i;
-                            }
-                        }
-                    }
-                    else if (rx1 < x2 && x2 < rx2)
-                    {
-                        r.setX (x2);
-                        r.setWidth (rx2 - x2);
-
-                        if (ry1 < y1 || y2 < ry2 || rx1 < x1)
-                        {
-                            if (const RectangleType newRect (rx1, ry1, x2 - rx1, ry2 - ry1); isNotEqual (newRect))
-                            {
-                                rects.insert (++i, newRect);
-                                ++i;
-                            }
-                        }
-                    }
-                    else if (ry1 < y1 && y1 < ry2)
-                    {
-                        if (x1 <= rx1 && rx2 <= x2 && ry2 <= y2)
-                        {
-                            r.setHeight (y1 - ry1);
-                        }
-                        else
-                        {
-                            if (const RectangleType newRect (rx1, ry1, rx2 - rx1, y1 - ry1); isNotEqual (newRect))
-                            {
-                                r.setY (y1);
-                                r.setHeight (ry2 - y1);
-
-                                rects.insert (++i, newRect);
-                                ++i;
-                            }
-                        }
-                    }
-                    else if (ry1 < y2 && y2 < ry2)
-                    {
-                        r.setY (y2);
-                        r.setHeight (ry2 - y2);
-
-                        if (rx1 < x1 || x2 < rx2 || ry1 < y1)
-                        {
-                            if (const RectangleType newRect (rx1, ry1, rx2 - rx1, y2 - ry1); isNotEqual (newRect))
-                            {
-                                rects.insert (++i, newRect);
-                                ++i;
-                            }
-                        }
-                    }
-                    else
-                    {
-                        rects.remove (i);
-                    }
-                }
-            }
+            rects.resize (alternativeRepresentation.size());
+            std::copy (alternativeRepresentation.begin(), alternativeRepresentation.end(), rects.begin());
+        }
+        else
+        {
+            subtract (rects, rect);
         }
     }
 
@@ -574,7 +483,7 @@ public:
                 auto jry2 = jry1 + r2.getHeight();
 
                 // if the vertical edges of any blocks are touching and their horizontals don't
-                // line up, split them horizontally..
+                // line up, split them horizontally
                 if (jrx1 == rx2 || jrx2 == rx1)
                 {
                     if (jry1 > ry1 && jry1 < ry2)
@@ -687,6 +596,130 @@ public:
     }
 
 private:
+    using PointType = Point<ValueType>;
+
+    struct AABB
+    {
+        AABB() = default;
+        AABB (const RectangleType& r) : tl (r.getTopLeft()), br (r.getBottomRight()) {}
+        AABB (PointType a, PointType b) : tl (a), br (b) {}
+        operator RectangleType() const { return RectangleType { tl, br }; }
+
+        bool completelyOutside (const AABB& other) const
+        {
+            return other.br.x <= tl.x || br.x <= other.tl.x || other.br.y <= tl.y || br.y <= other.tl.y;
+        }
+
+        PointType tl, br;
+    };
+
+    static PointType getTL (const AABB& aabb)
+    {
+        return aabb.tl;
+    }
+
+    static PointType getBR (const AABB& aabb)
+    {
+        return aabb.br;
+    }
+
+    static PointType getTL (const RectangleType& r)
+    {
+        return r.getTopLeft();
+    }
+
+    static PointType getBR (const RectangleType& r)
+    {
+        return r.getBottomRight();
+    }
+
+    template <typename Rect>
+    static void subtract (Array<Rect>& rectList, RectangleType rect)
+    {
+        jassert (! rectList.isEmpty());
+
+        const AABB rAABB { getTL (rect), getBR (rect) };
+
+        for (int i = rectList.size(); --i >= 0;)
+        {
+            auto& iRef = rectList.getReference (i);
+            const AABB iAABB { getTL (iRef), getBR (iRef) };
+
+            if (iAABB.completelyOutside (rAABB))
+                continue;
+
+            std::invoke ([&]
+            {
+                // For each rectangle in the list, we check for an overlap with the parameter rect
+                // and subdivide the list rectangles as necessary.
+                // The checks for each list rectangle happen in two stages, treating first the X
+                // then the Y axis as the 'major' axis. The terms 'major' and 'minor' are somewhat
+                // arbitrary. Essentially, in each pass, the rectangles in the list are only
+                // modified and/or subdivided on the major axis, without changing any minor axis
+                // coordinates. Subdividing an overlapping rect in this way may produce new rects
+                // that still overlap with the parameter rect. However, those will get cleaned up
+                // on the subsequent pass, where the major/minor axes are swapped.
+
+                struct Fields
+                {
+                    ValueType PointType::* major;
+                    ValueType PointType::* minor;
+                };
+
+                for (const auto& fields : { Fields { &PointType::x, &PointType::y },
+                                            Fields { &PointType::y, &PointType::x } })
+                {
+                    const auto replaceMajor = [&] (auto modified, const auto& replacement)
+                    {
+                        modified.*(fields.major) = replacement.*(fields.major);
+                        return modified;
+                    };
+
+                    const auto insert = [&] (const PointType& rAABBpt)
+                    {
+                        rectList.insert (++i, { iAABB.tl, replaceMajor (iAABB.br, rAABBpt) });
+                        ++i;
+                    };
+
+                    if (   iAABB.tl.*(fields.major) < rAABB.tl.*(fields.major)
+                        && rAABB.tl.*(fields.major) < iAABB.br.*(fields.major))
+                    {
+                        if (   rAABB.tl.*(fields.minor) <= iAABB.tl.*(fields.minor)
+                            && iAABB.br.*(fields.minor) <= rAABB.br.*(fields.minor)
+                            && iAABB.br.*(fields.major) <= rAABB.br.*(fields.major))
+                        {
+                            iRef = { iAABB.tl, replaceMajor (iAABB.br, rAABB.tl) };
+                        }
+                        else
+                        {
+                            iRef = { replaceMajor (iAABB.tl, rAABB.tl), iAABB.br };
+                            insert (rAABB.tl);
+                        }
+
+                        return;
+                    }
+
+                    if (   iAABB.tl.*(fields.major) < rAABB.br.*(fields.major)
+                        && rAABB.br.*(fields.major) < iAABB.br.*(fields.major))
+                    {
+                        iRef = { replaceMajor (iAABB.tl, rAABB.br), iAABB.br };
+
+                        if (   iAABB.tl.*(fields.minor) < rAABB.tl.*(fields.minor)
+                            || rAABB.br.*(fields.minor) < iAABB.br.*(fields.minor)
+                            || iAABB.tl.*(fields.major) < rAABB.tl.*(fields.major))
+                        {
+                            insert (rAABB.br);
+                        }
+
+                        return;
+                    }
+                }
+
+                rectList.remove (i);
+            });
+        }
+    }
+
     //==============================================================================
     Array<RectangleType> rects;
 };
