@@ -153,7 +153,7 @@
 
 extern "C"
 {
-#include <juce_graphics/unicode/sheenbidi/Headers/SheenBidi.h>
+#include <juce_graphics/unicode/sheenbidi/Headers/SheenBidi/SheenBidi.h>
 } // extern "C"
 
 #if JUCE_UNIT_TESTS
@@ -209,6 +209,7 @@ extern "C"
 #if JUCE_UNIT_TESTS
  #include "geometry/juce_Parallelogram_test.cpp"
  #include "geometry/juce_Rectangle_test.cpp"
+ #include "geometry/juce_RectangleList_test.cpp"
 #endif
 
 #if JUCE_USE_FREETYPE
