@@ -35,23 +35,6 @@
 namespace juce
 {
 
-Typeface::Ptr Font::Native::getDefaultPlatformTypefaceForFont (const Font& font)
-{
-    Font f (font);
-    f.setTypefaceName ([&]() -> String
-                       {
-                           const auto faceName = font.getTypefaceName();
-
-                           if (faceName == Font::getDefaultSansSerifFontName())    return "Roboto";
-                           if (faceName == Font::getDefaultSerifFontName())        return "Roboto";
-                           if (faceName == Font::getDefaultMonospacedFontName())   return "Roboto";
-
-                           return faceName;
-                       }());
-
-    return Typeface::createSystemTypefaceFor (f);
-}
-
 //==============================================================================
 #define JNI_CLASS_MEMBERS(METHOD, STATICMETHOD, FIELD, STATICFIELD, CALLBACK) \
  STATICMETHOD (create,          "create",           "(Ljava/lang/String;I)Landroid/graphics/Typeface;") \
@@ -100,14 +83,19 @@ DECLARE_JNI_CLASS (JavaMessageDigest, "java/security/MessageDigest")
 DECLARE_JNI_CLASS (AndroidAssetManager, "android/content/res/AssetManager")
 #undef JNI_CLASS_MEMBERS
 
+#define JUCE_INTRODUCED_IN_29 \
+    JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE("-Wgnu-zero-variadic-macro-arguments") \
+    __INTRODUCED_IN (29)                                                       \
+    JUCE_END_IGNORE_WARNINGS_GCC_LIKE
+
 // Defined in juce_core
 std::unique_ptr<InputStream> makeAndroidInputStreamWrapper (LocalRef<jobject> stream);
 
 struct AndroidCachedTypeface
 {
-    std::shared_ptr<hb_font_t> font;
+    HbFont font;
     GlobalRef javaFont;
-    TypefaceAscentDescent nonPortableMetrics;
+    TypefaceAscentDescent metrics;
 };
 
 //==============================================================================
@@ -116,7 +104,7 @@ class MemoryFontCache : public DeletedAtShutdown
 public:
     using Value = AndroidCachedTypeface;
 
-    ~MemoryFontCache()
+    ~MemoryFontCache() override
     {
         clearSingletonInstance();
     }
@@ -124,7 +112,7 @@ public:
     struct Key
     {
         String name, style;
-        auto tie() const { return std::tuple (name, style); }
+        [[nodiscard]] auto tie() const { return std::tuple (name, style); }
         bool operator< (const Key& other) const { return tie() < other.tie(); }
         bool operator== (const Key& other) const { return tie() == other.tie(); }
     };
@@ -247,7 +235,7 @@ public:
             {
                 return new AndroidTypeface (DoCache::no,
                                             result->font,
-                                            result->nonPortableMetrics,
+                                            result->metrics,
                                             font.getTypefaceName(),
                                             font.getTypefaceStyle(),
                                             result->javaFont);
@@ -263,7 +251,7 @@ public:
             return {};
         }
 
-        HbFont hbFont { hb_font_create (face.get()) };
+        HbFont hbFont { hb_font_create (face.get()), IncrementRef::no };
         FontStyleHelpers::initSynthetics (hbFont.get(), font);
 
         const auto androidFont = shouldStoreAndroidFont (face.get())
@@ -283,11 +271,6 @@ public:
         return fromMemory (DoCache::yes, blob, index);
     }
 
-    Native getNativeDetails() const override
-    {
-        return Native { hbFont.get(), nonPortableMetrics, this };
-    }
-
     Typeface::Ptr createSystemFallback (const String& text, const String& language) const override
     {
         if (__builtin_available (android 29, *))
@@ -305,6 +288,11 @@ public:
                 c->remove ({ getName(), getStyle() });
     }
 
+    const Native* getNativeDetails() const override
+    {
+        return native.get();
+    }
+
     static Typeface::Ptr findSystemTypeface()
     {
         if (__builtin_available (android 29, *))
@@ -313,6 +301,23 @@ public:
         return from (FontOptions{}.withName ("Roboto"));
     }
 
+    static JUCE_INTRODUCED_IN_29 Typeface::Ptr findGenericTypefaceWithMatcher (const char* name)
+    {
+        using AFontMatcherPtr = std::unique_ptr<AFontMatcher, FunctionPointerDestructor<AFontMatcher_destroy>>;
+        using AFontPtr = std::unique_ptr<AFont, FunctionPointerDestructor<AFont_close>>;
+
+        constexpr uint16_t testString[] { 't', 'e', 's', 't' };
+
+        const AFontMatcherPtr matcher { AFontMatcher_create() };
+        const AFontPtr matched { AFontMatcher_match (matcher.get(),
+                                                     name,
+                                                     testString,
+                                                     std::size (testString),
+                                                     nullptr) };
+
+        return fromMatchedFont (matched.get());
+    }
+
 private:
     enum class DoCache
     {
@@ -320,14 +325,7 @@ private:
         yes
     };
 
-    // The definition of __BIONIC_AVAILABILITY was changed in NDK 28.1 and it now has variadic
-    // parameters.
-    //
-    // But __INTRODUCED_IN only has one parameter so there isn't even a way to pass on anything to
-    // to __BIONIC_AVAILABILITY.
-    JUCE_BEGIN_IGNORE_WARNINGS_GCC_LIKE ("-Wgnu-zero-variadic-macro-arguments")
-
-    static __INTRODUCED_IN (29) Typeface::Ptr fromMatchedFont (AFont* matched)
+    static JUCE_INTRODUCED_IN_29 Typeface::Ptr fromMatchedFont (AFont* matched)
     {
         if (matched == nullptr)
         {
@@ -348,32 +346,20 @@ private:
         return cache->get ({ matchedFile, (int) matchedIndex }, &loadCompatibleFont);
     }
 
-    static __INTRODUCED_IN (29) Typeface::Ptr findSystemTypefaceWithMatcher()
+    static JUCE_INTRODUCED_IN_29 Typeface::Ptr findSystemTypefaceWithMatcher()
     {
-        using AFontMatcherPtr = std::unique_ptr<AFontMatcher, FunctionPointerDestructor<AFontMatcher_destroy>>;
-        using AFontPtr = std::unique_ptr<AFont, FunctionPointerDestructor<AFont_close>>;
-
-        constexpr uint16_t testString[] { 't', 'e', 's', 't' };
-
-        const AFontMatcherPtr matcher { AFontMatcher_create() };
-        const AFontPtr matched { AFontMatcher_match (matcher.get(),
-                                                     "system-ui",
-                                                     testString,
-                                                     std::size (testString),
-                                                     nullptr) };
-
-        return fromMatchedFont (matched.get());
+        return findGenericTypefaceWithMatcher ("system-ui");
     }
 
-    __INTRODUCED_IN (29) Typeface::Ptr matchWithAFontMatcher (const String& text, const String& language) const
+    JUCE_INTRODUCED_IN_29 Typeface::Ptr matchWithAFontMatcher (const String& text, const String& language) const
     {
         using AFontMatcherPtr = std::unique_ptr<AFontMatcher, FunctionPointerDestructor<AFontMatcher_destroy>>;
         using AFontPtr = std::unique_ptr<AFont, FunctionPointerDestructor<AFont_close>>;
 
         const AFontMatcherPtr matcher { AFontMatcher_create() };
 
-        const auto weight = hb_style_get_value (hbFont.get(), HB_STYLE_TAG_WEIGHT);
-        const auto italic = hb_style_get_value (hbFont.get(), HB_STYLE_TAG_ITALIC) != 0.0f;
+        const auto weight = hb_style_get_value (native->getFont(), HB_STYLE_TAG_WEIGHT);
+        const auto italic = hb_style_get_value (native->getFont(), HB_STYLE_TAG_ITALIC) != 0.0f;
         AFontMatcher_setStyle (matcher.get(), (uint16_t) weight, italic);
 
         AFontMatcher_setLocales (matcher.get(), language.toRawUTF8());
@@ -381,7 +367,7 @@ private:
         const auto utf16 = text.toUTF16();
 
         const AFontPtr matched { AFontMatcher_match (matcher.get(),
-                                                     readFontName (hb_font_get_face (hbFont.get()),
+                                                     readFontName (hb_font_get_face (native->getFont()),
                                                                    HB_OT_NAME_ID_FONT_FAMILY,
                                                                    nullptr).toRawUTF8(),
                                                      unalignedPointerCast<const uint16_t*> (utf16.getAddress()),
@@ -391,8 +377,6 @@ private:
         return fromMatchedFont (matched.get());
     }
 
-    JUCE_END_IGNORE_WARNINGS_GCC_LIKE
-
     static bool shouldStoreAndroidFont (hb_face_t* face)
     {
         return (hb_ot_color_has_svg (face) || hb_ot_color_has_paint (face))
@@ -458,7 +442,7 @@ private:
         const auto metrics = findNonPortableMetricsForData (blob);
 
         return new AndroidTypeface (cache,
-                                    HbFont { hb_font_create (face.get()) },
+                                    HbFont (hb_font_create (face.get()), IncrementRef::no),
                                     metrics,
                                     readFontName (face.get(), HB_OT_NAME_ID_FONT_FAMILY, nullptr),
                                     readFontName (face.get(), HB_OT_NAME_ID_FONT_SUBFAMILY, nullptr),
@@ -477,20 +461,19 @@ private:
     }
 
     AndroidTypeface (DoCache cache,
-                     std::shared_ptr<hb_font_t> fontIn,
+                     HbFont fontIn,
                      TypefaceAscentDescent nonPortableMetricsIn,
                      const String& name,
                      const String& style,
                      GlobalRef javaFontIn)
         : Typeface (name, style),
-          hbFont (std::move (fontIn)),
           doCache (cache),
-          nonPortableMetrics (nonPortableMetricsIn),
-          javaFont (std::move (javaFontIn))
+          javaFont (std::move (javaFontIn)),
+          native (std::make_unique<Native> (TypefaceNativeOptions { std::move (fontIn), nonPortableMetricsIn, this }))
     {
         if (doCache == DoCache::yes)
             if (auto* c = MemoryFontCache::getInstance())
-                c->add ({ name, style }, { hbFont, javaFont, nonPortableMetrics });
+                c->add ({ name, style }, { fontIn, javaFont, nonPortableMetricsIn });
     }
 
     static std::tuple<MemoryBlock, TypefaceAscentDescent> getBlobForFont (const Font& font)
@@ -498,7 +481,7 @@ private:
         auto memory = loadFontAsset (font.getTypefaceName());
 
         if (! memory.isEmpty())
-            return std::tuple (memory, findNonPortableMetricsForAsset (font.getTypefaceName()));
+            return { memory, findNonPortableMetricsForAsset (font.getTypefaceName()) };
 
         const auto file = findFontFile (font);
 
@@ -514,7 +497,7 @@ private:
         MemoryBlock result;
         stream.readIntoMemoryBlock (result);
 
-        return std::tuple (stream.isExhausted() ? result : MemoryBlock{}, findNonPortableMetricsForFile (file));
+        return { stream.isExhausted() ? result : MemoryBlock{}, findNonPortableMetricsForFile (file) };
     }
 
     static File findFontFile (const Font& font)
@@ -621,7 +604,7 @@ private:
         return mapEntry;
     }
 
-    static TypefaceAscentDescent findNonPortableMetricsForFile (File file)
+    static TypefaceAscentDescent findNonPortableMetricsForFile (const File& file)
     {
         auto* env = getEnv();
         const LocalRef typeface { env->CallStaticObjectMethod (TypefaceClass,
@@ -680,22 +663,22 @@ private:
 
         auto* env = getEnv();
 
-        hb_glyph_extents_t extents{};
+        const auto extents = native->getGlyphExtents ((hb_codepoint_t) glyph);
 
-        if (! hb_font_get_glyph_extents (hbFont.get(), (hb_codepoint_t) glyph, &extents))
+        if (! extents.has_value())
         {
             // Trying to retrieve an image for a glyph that's not present in the font?
             jassertfalse;
             return {};
         }
 
-        const auto upem = (jint) hb_face_get_upem (hb_font_get_face (hbFont.get()));
+        const auto upem = (jint) hb_face_get_upem (hb_font_get_face (native->getFont()));
         constexpr jint referenceSize = 128;
 
-        const jint pixelW = (referenceSize * abs (extents.width))  / upem;
-        const jint pixelH = (referenceSize * abs (extents.height)) / upem;
-        const jint pixelBearingX = (referenceSize * extents.x_bearing) / upem;
-        const jint pixelBearingY = (referenceSize * extents.y_bearing) / upem;
+        const jint pixelW = (referenceSize * abs (extents->width))  / upem;
+        const jint pixelH = (referenceSize * abs (extents->height)) / upem;
+        const jint pixelBearingX = (referenceSize * extents->x_bearing) / upem;
+        const jint pixelBearingY = (referenceSize * extents->y_bearing) / upem;
 
         const jint pixelPadding = 2;
 
@@ -776,10 +759,9 @@ private:
                                                .followedBy (transform) } } };
     }
 
-    std::shared_ptr<hb_font_t> hbFont;
     DoCache doCache;
-    TypefaceAscentDescent nonPortableMetrics;
     GlobalRef javaFont;
+    std::unique_ptr<Native> native;
 };
 
 //==============================================================================
@@ -803,4 +785,37 @@ void Typeface::scanFolderForFonts (const File&)
     jassertfalse; // not currently available
 }
 
+//==============================================================================
+Typeface::Ptr Font::Native::getDefaultPlatformTypefaceForFont (const Font& font)
+{
+    const auto faceName = font.getTypefaceName();
+
+    const auto idealFace = std::invoke ([&]() -> Typeface::Ptr
+    {
+        if (__builtin_available (android 29, *))
+        {
+            if (faceName == Font::getDefaultSansSerifFontName())    return AndroidTypeface::findGenericTypefaceWithMatcher ("sans-serif");
+            if (faceName == Font::getDefaultSerifFontName())        return AndroidTypeface::findGenericTypefaceWithMatcher ("serif");
+            if (faceName == Font::getDefaultMonospacedFontName())   return AndroidTypeface::findGenericTypefaceWithMatcher ("monospace");
+        }
+
+        return nullptr;
+    });
+
+    if (idealFace != nullptr)
+        return idealFace;
+
+    Font f (font);
+    f.setTypefaceName (std::invoke ([&]() -> String
+    {
+        if (faceName == Font::getDefaultSansSerifFontName())    return "Roboto";
+        if (faceName == Font::getDefaultSerifFontName())        return "Roboto";
+        if (faceName == Font::getDefaultMonospacedFontName())   return "Roboto";
+
+        return faceName;
+    }));
+
+    return Typeface::createSystemTypefaceFor (f);
+}
+
 } // namespace juce
