@@ -92,7 +92,7 @@ void ComboBox::setTooltip (const String& newTooltip)
 //==============================================================================
 void ComboBox::addItem (const String& newItemText, int newItemId)
 {
-    // you can't add empty strings to the list..
+    // you can't add empty strings to the list
     jassert (newItemText.isNotEmpty());
 
     // IDs must be non-zero, as zero is used to indicate a lack of selection.
@@ -118,7 +118,7 @@ void ComboBox::addSeparator()
 
 void ComboBox::addSectionHeading (const String& headingName)
 {
-    // you can't add empty strings to the list..
+    // you can't add empty strings to the list
     jassert (headingName.isNotEmpty());
 
     if (headingName.isNotEmpty())
@@ -531,6 +531,9 @@ static void comboBoxPopupMenuFinishedCallback (int result, ComboBox* combo)
 
 void ComboBox::showPopup()
 {
+    if (! isEnabled())
+        return;
+
     if (! menuActive)
         menuActive = true;
 
