@@ -75,7 +75,6 @@ namespace ActiveXHelpers
         JUCE_COMRESULT GetBorder (LPRECT)                                       override { return E_NOTIMPL; }
         JUCE_COMRESULT RequestBorderSpace (LPCBORDERWIDTHS)                     override { return E_NOTIMPL; }
         JUCE_COMRESULT SetBorderSpace (LPCBORDERWIDTHS)                         override { return E_NOTIMPL; }
-        JUCE_COMRESULT SetActiveObject (IOleInPlaceActiveObject* a, LPCOLESTR)  override { activeObject = addComSmartPtrOwner (a); return S_OK; }
         JUCE_COMRESULT InsertMenus (HMENU, LPOLEMENUGROUPWIDTHS)                override { return E_NOTIMPL; }
         JUCE_COMRESULT SetMenu (HMENU, HOLEMENU, HWND)                          override { return S_OK; }
         JUCE_COMRESULT RemoveMenus (HMENU)                                      override { return E_NOTIMPL; }
@@ -83,6 +82,12 @@ namespace ActiveXHelpers
         JUCE_COMRESULT EnableModeless (BOOL)                                    override { return S_OK; }
         JUCE_COMRESULT TranslateAccelerator (LPMSG, WORD)                       override { return E_NOTIMPL; }
 
+        JUCE_COMRESULT SetActiveObject (IOleInPlaceActiveObject* a, LPCOLESTR)  override
+        {
+            activeObject = ComSmartPtr (a, IncrementRef::yes);
+            return S_OK;
+        }
+
         HRESULT OfferKeyTranslation (LPMSG lpmsg)
         {
             if (activeObject != nullptr)
@@ -116,8 +121,8 @@ namespace ActiveXHelpers
 
         JUCE_COMRESULT GetWindowContext (LPOLEINPLACEFRAME* lplpFrame, LPOLEINPLACEUIWINDOW* lplpDoc, LPRECT, LPRECT, LPOLEINPLACEFRAMEINFO lpFrameInfo) override
         {
-            /* Note: If you call AddRef on the frame here, then some types of object (e.g. web browser control) cause leaks..
-               If you don't call AddRef then others crash (e.g. QuickTime).. Bit of a catch-22, so letting it leak is probably preferable.
+            /* Note: If you call AddRef on the frame here, then some types of object (e.g. web browser control) cause leaks.
+               If you don't call AddRef then others crash (e.g. QuickTime). Bit of a catch-22, so letting it leak is probably preferable.
             */
             if (lplpFrame != nullptr) { frame->AddRef(); *lplpFrame = frame; }
             if (lplpDoc != nullptr)   *lplpDoc = nullptr;
